@@ -4,15 +4,22 @@ use warnings;
 
 package Pod::Elemental::Transformer::Splint::AttributeRenderer;
 
-our $VERSION = '0.1003'; # VERSION
+our $VERSION = '0.1100'; # VERSION
 # ABSTRACT: Role for attribute renderers
 
 use Moose::Role;
 use Pod::Simple::XHTML;
+use Types::Standard qw/Str/;
 
 with 'Pod::Elemental::Transformer::Splint::Util';
 requires 'render_attribute';
 
+has for => (
+    is => 'ro',
+    isa => Str,
+    required => 1,
+);
+
 1;
 
 __END__
@@ -27,7 +34,7 @@ Pod::Elemental::Transformer::Splint::AttributeRenderer - Role for attribute rend
 
 =head1 VERSION
 
-Version 0.1003, released 2016-01-11.
+Version 0.1100, released 2016-01-12.
 
 =head1 SOURCE
 
