@@ -4,15 +4,21 @@ use warnings;
 
 package Pod::Elemental::Transformer::Splint::MethodRenderer;
 
-our $VERSION = '0.1003'; # VERSION
+our $VERSION = '0.1100'; # VERSION
 # ABSTRACT: Role for method renderers
 
 use Moose::Role;
 use Pod::Simple::XHTML;
+use Types::Standard qw/Str/;
 
 with 'Pod::Elemental::Transformer::Splint::Util';
 requires 'render_method';
 
+has for => (
+    is => 'ro',
+    isa => Str,
+    required => 1,
+);
 
 1;
 
@@ -28,7 +34,7 @@ Pod::Elemental::Transformer::Splint::MethodRenderer - Role for method renderers
 
 =head1 VERSION
 
-Version 0.1003, released 2016-01-11.
+Version 0.1100, released 2016-01-12.
 
 =head1 SOURCE
 
